gen date = mofd(Date)
format date %tm
tsset date

*Increase matsize:
set matsize 1000

*Generate log transformed variables:
gen Lenergy = log10(ind_energy)
gen Lmaterials = log10(ind_materials)
gen Lindustrials = log10(ind_industrials)
gen Lconsdisc = log10(ind_consdisc)
gen Lconsstapl = log10(ind_consstapl)
gen Lhealth = log10(ind_health)
gen Lfinancials = log10(ind_financials)
gen Lit = log10(ind_it)
gen Ltelecom = log10(ind_telecom)
gen Lutilities = log10(ind_utilities)
gen LCPI = log10(CPI)
gen LTS = log10(abs(TS))
gen LIP = log10(IP)
gen LND = log10(ND)
gen LOP = log10(OP)
gen LVIX = log10(VIX)

*Generate First Difference of log transformed variables:
gen DLenergy = D.Lenergy
gen DLmaterials = D.Lmaterials
gen DLindustrials = D.Lindustrials
gen DLconsdisc = D.Lconsdisc
gen DLconsstapl = D.Lconsstapl
gen DLhealth = D.Lhealth
gen DLfinancials = D.Lfinancials
gen DLit = D.Lit
gen DLtelecom = D.Ltelecom
gen DLutilities = D.Lutilities
gen DLCPI = D.LCPI
gen DLTS = D.LTS
gen DLIP = D.LIP
gen DLND = D.LND
gen DLOP = D.LOP
gen DLVIX = D.LVIX

*Descriptive Statistics (1997M1-2016M12) - CPI Example:
summarize CPI if tin(,2016m12), detail
summarize DLCPI if tin(,2016m12), detail

*Hisograms of First Difference (1997M1-2016M12) - CPI Example:
histogram DLCPI if tin(,2016m12), normal xtitle("")

*Scatter plots of first difference (1997M1-2016M12) - Energy+CPI Example:
twoway (scatter DLCPI DLenergy if tin(,2016m12), xtitle("Energy") ytitle("CPI"))

*Correlations matrices at 1% level (1997M1-2016M12):
pwcorr ind_energy-VIX if tin(,2016m12), star(0.01)
pwcorr DLenergy-DLVIX if tin(,2016m12), star(0.01)

*ADF & PP Tests (run for all variables in Levels and First Difference)
*use # of lags based on AIC
*use trend option for CPI and industries in Levels
*CPI Example:
varsoc CPI if tin(,2016m12), maxlag(16)
dfuller CPI if tin(,2016m12), lags(14) trend
pperron CPI if tin(,2016m12), lags(14) trend

varsoc DLCPI if tin(,2016m12), maxlag(16)
dfuller DLCPI if tin(,2016m12), lags(13)
pperron DLCPI if tin(,2016m12), lags(13)

*Lag selection (use log transformed variables) 1997M1-2016M12:
varsoc Lenergy LCPI-LVIX if tin(,2016m12), maxlag(12)
varsoc Lmaterials LCPI-LVIX if tin(,2016m12), maxlag(12)
varsoc Lindustrials LCPI-LVIX if tin(,2016m12), maxlag(12)
varsoc Lconsdisc LCPI-LVIX if tin(,2016m12), maxlag(12)
varsoc Lconsstapl LCPI-LVIX if tin(,2016m12), maxlag(12)
varsoc Lhealth LCPI-LVIX if tin(,2016m12), maxlag(12)
varsoc Lfinancials LCPI-LVIX if tin(,2016m12), maxlag(12)
varsoc Lit LCPI-LVIX if tin(,2016m12), maxlag(12)
varsoc Ltelecom LCPI-LVIX if tin(,2016m12), maxlag(12)
varsoc Lutilities LCPI-LVIX if tin(,2016m12), maxlag(12)

*Johansen test for cointegration (in Levels) 1997M1-2016M12:
vecrank ind_energy CPI-VIX if tin(,2016m12)
vecrank ind_materials CPI-VIX if tin(,2016m12)
vecrank ind_industrials CPI-VIX if tin(,2016m12)
vecrank ind_consdisc CPI-VIX if tin(,2016m12)
vecrank ind_consstapl CPI-VIX if tin(,2016m12)
vecrank ind_health CPI-VIX if tin(,2016m12)
vecrank ind_financials CPI-VIX if tin(,2016m12)
vecrank ind_it CPI-VIX if tin(,2016m12)
vecrank ind_telecom CPI-VIX if tin(,2016m12)
vecrank ind_utilities CPI-VIX if tin(,2016m12)

*VAR (1997M1-2016M12) & Diagnostics for the Energy Model:
var DLenergy DLCPI-DLOP DLVIX100 if tin(,2016m12), lags(2)
varlmar
varnorm, jbera
varstable

*VECM (1997M1-2016M12) & Diagnostics - Materials Model Example:
vec Lmaterials LCPI-LVIX if tin(,2016m12), lags(3)
veclmar
vecnorm, jbera
vecstable

*Forecast for 2017 - Materials Model Example:
quietly vec Lmaterials LCPI-LVIX if tin(,2016m12), lags(3)
fcast compute m2_, step(12)
fcast graph m2_Lenergy, observed
*All variables:
fcast graph m2_Lenergy m2_LCPI m2_LTS m2_LIP m2_LND m2_LOP m2_LVIX, observed

*IRF Graphs - Materials Model Example:
quietly vec Lmaterials LCPI-LVIX if tin(,2016m12), lags(3)
irf create en1, set(vecintro, replace) step(12)
irf graph oirf, impulse(LCPI LTS LIP LND LOP LVIX) response(Lenergy) yline(0)


*VECM (1997M1-2016M12) for all models:
vec Lmaterial LCPI-LVIX if tin(,2016m12), lags(3)
vec Lindustrials LCPI-LVIX if tin(,2016m12), lags(3)
vec Lconsdisc LCPI-LVIX if tin(,2016m12), lags(3)
vec Lconsstapl LCPI-LVIX if tin(,2016m12), lags(3)
vec Lhealth LCPI-LVIX if tin(,2016m12), lags(3)
vec Lfinancials LCPI-LVIX if tin(,2016m12), lags(3)
vec Lit LCPI-LVIX if tin(,2016m12), lags(3)
vec Ltelecom LCPI-LVIX if tin(,2016m12), lags(3)
vec Lutilities LCPI-LVIX if tin(,2016m12), lags(3)
